@@ -46,7 +46,7 @@ class Command(BaseCommand):
         media = hasattr(settings, 'IUNO_INITIAL_MEDIA')
         if media:
             media = settings.IUNO_INITIAL_MEDIA
-            if not os.path.isdir("media") and os.path.isfile(media):
+            def extractMedia(media):
                 zf = zipfile.ZipFile(media)
                 zf.extractall('.')
                 zf.close()
@@ -55,6 +55,13 @@ class Command(BaseCommand):
                 if sysStr == "Linux":
                     os.system("convmv -f big5 -t utf8 -r --notest media")
                     
+            if not os.path.isdir("media"):
+                if os.path.isfile(media):
+                    extractMedia(media)
+            else:
+                if not os.listdir("media"):
+                    extractMedia(media)
+                    
         # Iuno initialdata
         initialData = hasattr(settings, 'IUNO_INITIAL_DATA')
         
