@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11745 2019-10-09 02:24:16Z Lavender $
+# $Id: forms.py 11751 2019-10-16 02:58:57Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-09 10:24:16 +0800 (週三, 09 十月 2019) $
-# $Revision: 11745 $
+# $Date: 2019-10-16 11:58:57 +0900 (週三, 16 十月 2019) $
+# $Revision: 11751 $
 
 import os
 import hashlib
@@ -29,6 +29,8 @@ from django.conf import settings
 
 from oscar import VERSION
 from oscar.core.loading import get_model, get_class, get_classes
+from oscar.forms.widgets import DatePickerInput
+from oscar.core.utils import datetime_combine
 from ckeditor_uploader.widgets import CKEditorUploadingWidget
 
 (RelatedFieldWidgetWrapper,
@@ -73,6 +75,61 @@ class ProductForm(_ProductForm):
             
 catalogueViews.ProductCreateUpdateView.form_class = ProductForm
 
+# Product Search
+_ProductSearchForm = get_class('dashboard.catalogue.forms', 'ProductSearchForm')
+Category = get_model('catalogue', 'Category')
+ProductClass = get_model('catalogue', 'ProductClass')
+
+class ProductSearchForm(_ProductSearchForm):
+    productClass = forms.ModelChoiceField(
+        label=_('Product type'),
+        queryset=ProductClass.objects.all(), required=False
+    )
+    category = forms.ModelChoiceField(
+        queryset=Category.objects.all(), 
+        label=_("Variants"), required=False
+    )
+    dateFrom = forms.DateField(
+        required=False, label=_("Date from"), widget=DatePickerInput)
+    dateTo = forms.DateField(
+        required=False, label=_("Date to"), widget=DatePickerInput)
+   
+    if VERSION >= (2, 0, 0):
+        notPublic = forms.BooleanField(
+            label=_('Not public'), required=False, initial=True)
+    
+_apply_search = catalogueViews.ProductListView.apply_search
+def apply_search(self, queryset):
+    self.form = self.form_class(self.request.GET)
+    if not self.form.is_valid():
+        return queryset
+    data = self.form.cleaned_data
+    
+    queryset = _apply_search(self, queryset)
+    
+    if data.get('category'):
+        queryset = queryset.filter(categories__in=[data['category'],])
+    if data.get('productClass'):
+        queryset = queryset.filter(product_class=data['productClass'])
+    if data.get('notPublic'):
+        queryset = queryset.filter(is_public=False)
+    if data['dateFrom'] and data['dateTo']:
+        dateTo = datetime_combine(data['dateTo'], datetime.time.max)
+        dateFrom = datetime_combine(data['dateFrom'], datetime.time.min)
+        queryset = queryset.filter(
+            date_updated__gte=dateFrom, date_updated__lt=dateTo)
+    elif data['dateFrom']:
+        dateFrom = datetime_combine(data['dateFrom'], datetime.time.min)
+        queryset = queryset.filter(date_updated__gte=dateFrom)
+    elif data['dateTo']:
+        dateTo = datetime_combine(data['dateTo'], datetime.time.max)
+        queryset = queryset.filter(date_updated__lt=dateTo)
+    
+    return queryset
+    
+catalogueViews.ProductListView.form_class = ProductSearchForm
+catalogueViews.ProductListView.apply_search = apply_search
+
 # content block ckeditor
 if not VERSION >= (2, 0, 0):
     # RawHTMLForm
